#
# spec file for package argocd-cli
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define __arch_install_post export NO_BRP_STRIP_DEBUG=true

%define executable_name argocd

Name:           argocd-cli
Version:        2.11.7
Release:        1.1
Summary:        CLI for the ArgoCD declarative continuous deployment tool
License:        Apache-2.0
URL:            https://github.com/argoproj/argo-cd
Source:         argo-cd-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  go >= 1.20

%description
Argo CD is a declarative, GitOps continuous delivery tool for Kubernetes.

This packages contains the CLI to interact with the ArgoCD installation in a Kubernetes cluster.

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%autosetup -p 1 -a 1 -n argo-cd-%{version}

%build
KUBECTL_VERSION=$(awk '/=> k8s.io\/kubectl v/ {print $4}' go.mod)
DATE_FMT="+%%Y-%%m-%%dT%%H:%%M:%%SZ"
BUILD_DATE=$(date -u -d "@${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u -r "${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u "${DATE_FMT}")
go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags="\
   -X github.com/argoproj/argo-cd/v2/common.version=%{version} \
   -X github.com/argoproj/argo-cd/v2/common.buildDate=$BUILD_DATE \
   -X github.com/argoproj/argo-cd/v2/common.gitCommit=v%{version} \
   -X github.com/argoproj/argo-cd/v2/common.gitTag=v%{version} \
   -X github.com/argoproj/argo-cd/v2/common.gitTreeState=clean \
   -X github.com/argoproj/argo-cd/v2/common.kubectlVersion=$KUBECTL_VERSION" \
   -o bin/%{executable_name} ./cmd/

%install
# Install the binary.
install -D -m 0755 bin/%{executable_name} "%{buildroot}/%{_bindir}/%{executable_name}"

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{executable_name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{executable_name}

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh_completion.d/
%{buildroot}/%{_bindir}/%{executable_name} completion zsh > %{buildroot}%{_datarootdir}/zsh_completion.d/_%{executable_name}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{executable_name}

%files -n %{name}-bash-completion
%dir %{_datarootdir}/bash-completion/completions/
%{_datarootdir}/bash-completion/completions/%{executable_name}

%files -n %{name}-zsh-completion
%defattr(-,root,root)
%dir %{_datarootdir}/zsh_completion.d/
%{_datarootdir}/zsh_completion.d/_%{executable_name}

%changelog
* Wed Jul 24 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.11.7:
  * Bump version to 2.11.7 (#19175)
  * Merge commit from fork
* Mon Jul 22 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.11.6:
  * Bump version to 2.11.6 (#19142)
  * Merge commit from fork
  * fix: cherry-pick #18761 (v2.11) (#19108)
* Tue Jul 16 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.11.5:
  * Bump version to 2.11.5 (#19061)
  * chore: update gitops-engine (2.11) (#19036)
  * fix(cli): Get Redis password from secret in `loadClusters()`
    (#18951) (#18956)
* Wed Jul  3 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.11.4:
  * remove unwanted updating of source-position in app set command
    (#18887) (#18896)
  * Bump version to 2.11.4 (#18894)
  * fix: update static schemas (#18889)
  * fix(controller): bad server-side diffs (#18213) (2.11) (#18868)
  * docs: Fix .path to .path.segments go template (#18872) (#18874)
  * fix(webhook): bitbucket and azure not triggering refresh
    (#18289) (#18765) (#18819)
  * fix(appset): revert "keep reconciling even when params error
    occurred" (#17062) (#18781)
  * fix: docs site version selector broken (#18378) (#18724)
  * fix: Update braces package to 3.0.3 (#18459) (#18663)
  * Revert "feat(server): log app Spec along with event (#16416)"
    (#18458) (#18639)
  * test: fix e2e tests after GHSA-3cqf-953p-h5cp (#18543) (#18641)
  * chore(deps): upgrade redis to 7.2.15-alpine (cherry-pick
    release-2.11) (#18640)
  * chore: bump go version to 1.21.10 (#18540)
* Fri Jun  7 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.11.3:
  * Bump version to 2.11.3 (#18520)
  * Merge pull request from GHSA-3cqf-953p-h5cp
  * Merge pull request from GHSA-87p9-x75h-p4j2
  * fix: app names with non-alphanumeric characters in position 63
    break syncs (issue #18237) (#18256) (#18439)
  * fix source ordering issue in manifest generation for
    multi-source app while using manifests and diff commands
    (#18395) (#18408)
* Thu May 23 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.11.2:
  * Bump version to 2.11.2 (#18384)
  * fix: remove Egress NetworkPolicy for argocd-redis and
    argocd-redis-ha-haproxy (#18367) (#18372)
  * fix: revert registry change (#18328)
  * fix(deps): upgrade otel dependency (#18285) (#18324)
  * docs: add v2.11 notes to upgrading page (#18333)
  * chore(ci): fix release notes (#18132) (#18330)
* Tue May 21 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.11.1:
  * Bump version to 2.11.1 (#18319)
  * Merge pull request from GHSA-9766-5277-j5hr
  * Merge pull request from GHSA-9766-5277-j5hr
  * fix: UI MultiSource - Helm Chart with values.yaml (#18188)
    (#18200)
  * fix: copy visited map #11699 (#12667) (#18219)
  * update resolveRevision to use the correct source for
    multi-source app (#18194) (#18202)
  * Fix logging hash with multiple sources (#18189) (#18193)
  * chore(deps): upgrade helm to 3.14.4 (#18255) (#18286)
  * chore(deps): cherry-pick bump protobuf #17788 (#18284)
  * chore: update gitops engine for force sync option (#5882) -
    2.11 (#18125)
* Wed May  8 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.11.0:
  Major Upgrade, please read the documentation:
  https://argo-cd.readthedocs.io/en/stable/operator-manual/upgrading/overview/
* Tue Apr 30 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.10.9:
  * Bump version to 2.10.9 (#18033)
  * fix: enable sha256 and sha512 for git ssh (#18028) (#18029)
* Fri Apr 26 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.10.8:
  * Bump version to 2.10.8 (#17990)
  * fix: codegen after security fix - 2.10 (#17985)
  * Merge pull request from GHSA-9m6p-x4h2-6frq
  * Merge pull request from GHSA-9m6p-x4h2-6frq
  * chore: upgrade redis to 7.0.15 (#17666)
  * fix: codegen and e2e tests in release-2.10 (#17844)
* Mon Apr 15 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.10.7:
  * fix: docker build fails due to "The repository
    'http://deb.debian.org/debian buster-backports Release' does
    not have a Release file."
  * Bump version to 2.10.7 (#17831)
  * Merge pull request from GHSA-2gvw-w6fj-7m3c
* Fri Apr  5 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.10.6:
  * Bump version to 2.10.6 (#17744)
  * fix(security): use Chainguard fork of git-urls (#17732)
    (#17735)
  * fix: fix calculating patch for respect ignore diff feature
    (#17693)
  * fix(ui): Fix color generation for pod name in logs viewer.
    Fixes #17704 (#17706) (#17710)
  * chore(deps): bump webpack-dev-middleware from 5.3.1 to 5.3.4 in
    /ui (#17598) (#17686)
* Sat Mar 30 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.10.5:
  * fix cosign (#17656)
  * Bump version to 2.10.5 (#17654)
  * Merge pull request from GHSA-jhwx-mhww-rgc3
  * fix: elements should be optional (#17424) (#17510)
* Mon Mar 18 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.10.4:
  * Bump version to 2.10.4 (#17557)
  * Merge pull request from GHSA-6v85-wr92-q4p7
  * Merge pull request from GHSA-2vgg-9h6w-m454
  * fix(notifications): Helm.GetParameterValueByName should take
    helm.parametes first (#17472) (#17512)
  * fix: registry argument to be only the host instead full URL
    (#17381) (#17534)
  * fix(ui): add confirmation box in resource summary delete action
    (#17485) (#17545)
  * chore(deps): upgrade helm to 3.14.3 (#17531) (#17533)
* Sat Mar 16 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.10.3:
  * Bump version to 2.10.3 (#17513)
  * Merge pull request from GHSA-g623-jcgg-mhmm
  * Merge pull request from GHSA-jwv5-8mqv-g387
  * fix: multi-source app breaks application parameters UI (#16910)
    (#17033) (#17332)
  * fix!: disable rate limiting completely by default (#17355)
    (#17393)
* Sat Mar 16 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.10.2:
  * chore(ci): free up disk space for goreleaser (#17373) (#17374)
  * Bump version to 2.10.2 (#17370)
  * fix(ui): The tiles in Applications List are too wide #17220
    (#17340) (#17351)
  * fix: The argocd server api-content-type flag does not allow
    empty content-type header (#17331) (#17346)
  * chore(deps): upgrade helm to 3.14.2 (#17330) (#17333)
  * Corrected certificate managment for OCI helm charts (#16656)
    (#17320)
  * chore(deps): upgrade helm to 3.14.1 (#17213) (#17216)
  * chore(deps): Upgrade aws-sdk-go to support eks pod identity
    (#17063) (#17225)
* Sat Mar 16 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.10.1:
  * Bump version to 2.10.1 (#17211)
  * fix(controller): add missing workqueue metrics (#16315)
    (#17013) (#17209)
  * fix: infer correct shard in statefulset setup (#17124, #17016)
    (#17167) (#17204)
  * fix: stop initializing deployment informer if dynamic sharding
    is disabled (#17097) (#17202)
  * fix(kustomize): set build dir (#15057) #16229 #16652 (#16653)
    (#17129)
  * fix(manifests): applicationset-controller dir is not added to
    cluster-rbac/kustomization.yaml. (#16810) (#17120)
  * chore(manifests): add ClsuterRole/ClusterRoleBinding for
    applicationset controller. (#16699) (#17119)
* Wed Feb 14 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.10.0:
  * Known Issues
  - 2.10.0 has a major issue in application controller running in
    HA mode. A fix will be in 2.10.1.
  * Changes
  - feat(controller): add sync jitter(#14241) (#16820) (#16960)
  - feat(ui): add status panel extensions (#15780)
  - feat: Implement Server-Side Diff (#13663)
  - feat(ui): Show prompt when every resource requires pruning
    (#16603)
  - feat: PostDelete hook support (#16595)
  - feat(security): log user when access is blocked (#16558)
  - feat(ui): Add sourceNamespaces in Projects UI and only show
    it if AppsInAnyNamespaceEnabled flag is set (#16249)
  - feat(appset): Advanced Templating using templatePatch
    (#14893)
  - feat: Argocd notification self service (#16488)
  - feat(cli): Added example to admin-cluster.go and
    projectwindow.go files (#16128)
  - feat(server): log app Spec along with event (#16416)
  - feat(opentelemetry): ✨ support for secured OTLP endpoint and
    headers (#15573)
  - feat(oidc): optionally query OIDC UserInfo to gather group
    claims (#12062)
  - feat(app): Support app sync --dry-run --revision
    some-revision with arbitrary revisions(#12592) (#16387)
  - feat: add support for ALL_PROXY (#10451)
  - feat(appset): Added 'slugify' sprig function (#15188)
  - feat: Support for Kustomize Components (#16230)
  - feat: add retry logic for k8s client #7692 (#16154)
  - feat: grace period for repo errors to prevent aggressive
    unknown sync state (#16085)
  - feat: add examples to --help output for admin.go file
    (#16030)
  - feat: add examples to --help ouput for argocd_server.go file
    (#16032)
  - feat: Allow 'both' option for uibannerposition (#14623)
  - feat: PKCE authentication flow for web logins #9890 (#15889)
  - feat(cli): example for generate-allow-list (#16136)
  - feat(cli): Add examples to --help output for get KEYID
    (#16019)
  - feat(cli): Add examples to --help output for "gpg_list"
    (#16017)
  - feat: Add examples to --help output for remaining "create
    PROJECT ROLE-NAME" (#15983)
  - feat(cli): Add examples to argocd proj role cli family
    (#15875)
  - feat(cli): add admin-app-example (#15690) (#15861)
  - feat(cli): add project flag to avoid permission denied errors
    on 404 (#16040)
  - feat: expose notification secrets for request payload
    templating (#16055)
  - feat: make git requests configurable (#15646)
  - feat: add write back to application informer (#15987)
  - feat(cli): Add examples to --help output for "list PROJECT"
    (#16033)
  - feat(cli): Add examples to --help output for "gpg add"
    (#16020)
  - feat(ui): Recursive Helm Values files detection (#15935)
    (#15936)
  - feat: use rate limited queue (#15480)
  - feat: Add examples to --help output for remaining "get
    APPNAME" (#15862)
  - feat(cli): add the repocred-list-example (#15690) (#15869)
  - feat(cli): add the cluster-list-example (#15690) (#15866)
  - feat: Add examples to --help output for "delete PROJECT
    ROLE-NAME" (#15986)
  - feat(cli): Add examples to projectwindows.go (#15860)
  - feat(health): add iammanager.keikoproj.io/Iamrole health
    check (#15899)
  - feat: Add examples to --help output for "generate-spec
    PROJECT" (#15871)
  - feat(cli): add the repo-example (#15690) (#15865)
  - feat(cli): Add examples to --help output for "set APPNAME"
    (#15872)
  - feat(cli): Add examples to --help output for "logs APPNAME"
    (#15873)
  - feat(cli): Add example to argocd relogin command (#15839)
  - feat: Add examples to --help output for all "argocd proj"
    cmds (#15824)
  - feat(cli): Added example to --help output for bcrypt (#15838)
  - feat(cli): Add example to --help output for app actions
    (#15822)
  - feat(cli): Add examples to --help output for remaining
    "argocd account" (#15814)
  - feat(cli): Add examples to --help output for remaining
    "argocd repocreds" cmds (#15846)
  - feat(cli): Add example to --help output 1 (#15782)
  - feat(cli): Added example to --help output for context
    (#15809)
  - feat(ci): retry individual e2e tests (#15696)
  * Bug fixes (47)
  - fix(ci): correct helm checksum path (#17081) (#17083)
  - fix(controller): fix application controller deployment
    crashing (#16984) (#17093)
  - fix(server): allow disabling content-type check (#16959)
    (#16976)
  - fix(appcontroller): Uptake fix in gitops engine which fixes
    application sync with auto create ns and server side apply
    (#16942) (#16963)
  - fix: Use the cache for sharding (#15237) (#16902)
  - fix: enforce content type header for API requests (#16860)
    (#16877)
  - fix(appset): Use case insensitive comparison of repo details
    in appset webhook handler (#16503) (#16504)
  - fix(cli): argocd admin settings resource-overrides health to
    not ignore wildard customizations (#16461)
  - fix(repo-server): excess git requests, short-circuit
    GenerateManifests ref only (#16501)
  - fix(appset): Always remove ownerReferences when appset policy
    doesn't allow app's deletion (#12172) (#16506)
  - fix(ui): use background delete to match k8s terminology
    (#15579)
  - fix: Use math.MaxInt (instead of math.MaxInt64) to fix builds
    on 32bit platforms (#16065)
  - fix: cert-manager.io/certificate health.lua for consistent
    issuing (Issue #16523) (#16520)
  - fix(doc): Fix documentation templatePatch (#16522)
  - fix: Tooltips point in wrong direction#11935 (#12578)
  - fix(ui): add exec check to avoid API calls (#16168)
  - fix PerconaXtraDBCluster health (#16434)
  - fix(controller): Address diff cache miss issues (#16458)
  - fix(cli): pass redis compression to cluster stats and shards
    commands (#16060) (#16421)
  - fix: upgrade notifications-engine (#16354)
  - fix(ui): User Info blob is too far to the right relative to
    Applications/Settings/Documentation (#12016)
  - fix: fixed cli admin dashboard cmd (#16430)
  - fix(appset): use topics for Gitlab SCM Provider (#13169)
    (#13170)
  - fix(appset): prevent app deletion according to appset policy
    (#12172) (#15903)
  - fix: failing lint and unit test (#16275)
  - fix(appset): Fix name conflict in appset controller (#16207)
    (#16222)
  - fix(ui): summary: fix sync options block layout (#16152)
  - fix api docs (#16186)
  - fix(ui): Improve apps tiles view (#16140)
  - fix(appset): ignoreApplicationDifferences not working
    (#15965)
  - fix: rbac validate command can now take either namespace or
    policy-file (#15543)
  - fix: Add timezone to projectwindows list (#15929)
  - fix(banzai/KafkaCluster): Update health.lua (#15962)
  - fix(docs): proj role list example (#16074)
  - fix: list manually provided external urls before generated
    ones (#13296)
  - fix: Add ENV variable to configure GRPC Keep Alive Time
    (#15656) (#15806)
  - fix: delete event cache deadlock test flakiness (#15964)
  - fix(ci): unstable integration test (#15976)
  - fix: update docs for ApplicationService.Get to reflect
    reality (#15927)
  - fix: Replace antonmedv/expr with expr-lang/expr (#15879)
  - fix(notifications): Allow notifications controller to notify
    on all namespaces (#15702)
  - fix(cli): Do not error out with no errors (#15688)
  - fix: codeowners syntax error (#15781)
  - fix(appset): add option to disable SCM providers entirely
    (#14246) (#15248)
  - fix(applicationset): git generator ignores empty files
    (#15661)
  - fix(ci): misplaced config option (#15698)
  - fix(ci): do not fail fast on e2e test failures (#15694)
  * Documentation (39)
  - docs(hooks): add postdelete to table (#17048) (#17051)
  - docs(kustomize): add components yaml example (#17043)
    (#17046)
  - docs(argocd-cm): add timeout.reconciliation.jitter example
    (#17044) (#17047)
  - docs(applicationset): explain impact of empty spec in
    templatePatch (#17042) (#17045)
  - docs: add context to configmap example (#16763) (#16764)
  - docs: configmap items are strings (#16737) (#16738)
  - docs: add documentation for the argocd cluster commands
    (#16555)
  - docs: update telepresence quickstart link (#16616)
  - docs: callout the need to restart pods to pickup service
    accounts (#16610)
  - docs: fix indentation for preserve file mode (#16598)
  - docs(monitoring): add new ServiceMonitors for redis, dex,
    notifications (#16534)
  - docs: fix broken link in secret-management.md (#16588)
  - docs: Add Kong Inc. as a user (#16582)
  - docs: Fix minor typo in Declarative Setup (#16550)
  - docs: fix kustomize patches example (#16353)
  - docs: Katie as Release Champion for 2.10 and Added a column
    for Release Approver (#16341)
  - docs: update release doc and issue template (#16329)
  - docs: fix upgrade instructions (#16326)
  - docs: Add @gdsoumya to approvers in OWNERS (#16331)
  - docs: Document ApplyOutOfSyncOnly in application spec
    (#16282)
  - docs: add Axians ACSP to users (#16226)
  - docs: Ensure consistent proper case of Kubernetes (#16205)
  - docs: Add Semgrep as a user (#16185)
  - docs(cmp): Document ConfigManagementPlugin.spec.version more
    clearly (#15974)
  - docs(appset): ApplicationSets generators docs to use go
    templates (#16109) (#16127)
  - docs: added identity-center.md doc for AWS SSO (#15689)
  - docs(bounty): proposal for feature to hide anno...
* Sat Feb  3 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.9.6:
  * Bump version to 2.9.6 (#17078)
  * chore(deps): rm go-jose Cxb6dee8d5-b814 high vuln (#16947)
    (#16970) (#17056)
  * fix(redis): go-redis v9 regression missing metrics and
    reconnect hook (#13415) (#15275) (#17024)
  * fix(ui): Badge for apps in any namespace (#16739) (#17008)
  * fix(server): allow disabling content-type check (#16959)
    (#16977)
* Sat Jan 20 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.9.5:
  * Bump version to 2.9.5 (#16937)
  * fix(ui): set content-type for certain UI requests (#16923)
    (#16930) (#16933)
* Sat Jan 20 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.9.4:
  * Bump version to 2.9.4 (#16917)
  * chore(deps): bump github.com/go-git/go-git/v5 from 5.8.1 to
    5.11.0 (#16912)
  * fix: enforce content type header for API requests (#16860)
    (Cherry-pick release-2.9 ) (#16878)
  * fix: add list permission deployments (#16785) (#16804)
  * fix(ui):Fixed log horizontal scroll for issue #16411 (#16727)
    (#16761)
  * fix(action): Add missing owner refs and annotation to
    create-job action (#16607) (#16608)
  * Added missing 'alias:' prefix for repository name as described
    here: (#15902) (#16535)
  * fix(grpcproxy): add missing GRPCKeepAliveEnforcementMinimum
    (#15708) (#16576)
  * fix(appset): don't emit k8s events for unchanged apps, log at
    debug (#16562)
  * docs: Fix format issue in rbac.md (#16521) (#16538)
  * chore: upgrade k8s client from v0.24.2 to v0.24.17 (#16554)
  * fix(appset): Don't use revision cache when reconciling after
    webhook (#16062) (#16241) (#16536)
* Sun Dec  3 2023 kastl@b1-systems.de
- Update to version 2.9.3:
  * Bump version to 2.9.3 (#16510)
  * fix(repo-server): excess git requests, resolveReferencedSources
    and runManifestGenAsync not using cache (Issue #14725) (#16410)
    (#16494)
  * fix(controller): Address diff cache miss issues (#16458)
    (#16485)
  * fix: cherry-pick fixed cli admin dashboard cmd (#16457)
  * fix(ui): Issues with overlapping content in the app details
    view on smaller screens (#16268) (#16407)
* Tue Nov 21 2023 kastl@b1-systems.de
- Update to version 2.9.2:
  * Bump version to 2.9.2 (#16405)
  * feat: add support for ALL_PROXY (#10451) (#16401)
  * fix: set max for max cookie number to `math.MaxInt` (#16388)
    (#16397)
  * docs: fix documentation of ignoreApplicationDifferences
    (#16365) (#16380)
  * bump helm 3.13.2 (#16344)
  * fix: check for double definition (#16335)
  * docs: fix upgrade instructions (#16327)
* Fri Nov 17 2023 Johannes Kastl <kastl@b1-systems.de>
- new package argocd-cli: CLI for the ArgoCD declarative continuous
  deployment tool
